==> jena-arq-2.9.4-sources.jar: com/hp/hpl/jena/sparql/util/PrintSerializableBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hp.hpl.jena.sparql.util;

import org.openjena.atlas.io.IndentedWriter ;
import org.openjena.atlas.io.PrintUtils ;

import com.hp.hpl.jena.shared.PrefixMapping ;
import com.hp.hpl.jena.sparql.engine.Plan ;

public abstract class PrintSerializableBase implements PrintSerializable
{
    @Override
    public String toString(PrefixMapping pmap)
    { return QueryOutputUtils.toString(this, pmap) ; }

    // final stops it being overridden and missing the output() route.
    @Override
    public final String toString()
    { return PrintUtils.toString(this) ; }
    
    /** Normally overridden for better information */ 
    @Override
    public void output(IndentedWriter out)
    {
        out.print(Plan.startMarker) ;
        out.print(Utils.className(this)) ;
        out.print(Plan.finishMarker) ;
    }
}

==> jena-arq-2.10.0-sources.jar: com/hp/hpl/jena/sparql/util/PrintSerializableBase.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.hp.hpl.jena.sparql.util;

import org.apache.jena.atlas.io.IndentedWriter ;
import org.apache.jena.atlas.io.PrintUtils ;

import com.hp.hpl.jena.shared.PrefixMapping ;
import com.hp.hpl.jena.sparql.engine.Plan ;

public abstract class PrintSerializableBase implements PrintSerializable
{
    @Override
    public String toString(PrefixMapping pmap)
    { return QueryOutputUtils.toString(this, pmap) ; }

    // final stops it being overridden and missing the output() route.
    @Override
    public final String toString()
    { return PrintUtils.toString(this) ; }
    
    /** Normally overridden for better information */ 
    @Override
    public void output(IndentedWriter out)
    {
        out.print(Plan.startMarker) ;
        out.print(Utils.className(this)) ;
        out.print(Plan.finishMarker) ;
    }
}
